@@ -3,7 +3,7 @@ package Data::Cmp;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-04-12'; # DATE
 our $DIST = 'Data-Cmp'; # DIST
-our $VERSION = '0.008'; # VERSION
+our $VERSION = '0.009'; # VERSION
 
 use 5.010001;
 use strict;
@@ -106,7 +106,7 @@ Data::Cmp - Compare two data structures, return -1/0/1 like cmp
 
 =head1 VERSION
 
-This document describes version 0.008 of Data::Cmp (from Perl distribution Data-Cmp), released on 2021-04-12.
+This document describes version 0.009 of Data::Cmp (from Perl distribution Data-Cmp), released on 2021-04-12.
 
 =head1 SYNOPSIS
 
@@ -134,9 +134,11 @@ Sort data structures (of similar structures):
 
 This relatively lightweight (no non-core dependencies, under 100 lines of code)
 module offers the C<cmp_data> function that, like Perl's C<cmp>, returns -1/0/1
-value. In addition to that, it can also return 2 if the two data structures
-differ but no comparable: there is no sensible notion of which one is "greater
-than" the other.
+value. C<cmp_data> differs from C<cmp> in that it can compare two data of
+different types and compare data items recursively, with pretty sensible
+semantics. In addition to returning -1/0/1, C<cmp_data> can also return 2 if two
+data differ but not comparable when there is no sensible notion of which one is
+"greater than" the other, for example empty hash C<{}> vs empty array C<[]>).
 
 This module can handle circular structure.
 
